#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_TIMES_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_TIMES_HPP_INCLUDED

#include <boost/simd/operator/include/functions/times.hpp>

#endif
